/**********************************************************************
* File: 78M6610_LMU.h
* Programmer: Justin Jordan
* Started: 17JUN14
* Updated: 14AUG14
*
* Description: 78M6610+LMU addresses and specific commands.
*
**********************************************************************/


#ifndef __78M6610_LMU_H
#define __78M6610_LMU_H

#define MAX_PACKET_LEN 255 

#define MAX_REG_ADRS 0xB3  //max word address

/******************** 78M6610+LMU register defenitions **************** 
  Names follow word addresses; 0, 1, 2, etc.  maxim_ssi.c functions 
  that use these addresses will multiply by 3 to get byte addresses, 
  just use the name of the address in the argument of the functions.
**********************************************************************/
typedef enum 
{
  COMMAND,
  FW_DATE,
  MASK0,
  MASK4,
  MASK6,
  MASK7,
  MASK10,
  STICKY,
  SAMPLES,
  CAL_CYCS,
  PHASE_COMP1,
  PHASE_COMP3,
  S1_GAIN,
  S0_GAIN,
  S3_GAIN,
  S2_GAIN,
  S1_OFFS,
  S0_OFFS,
  S3_OFFS,
  S2_OFFS,
  T_GAIN,
  T_OFFS,
  HPF_COEF_I,
  HPF_COEF_V,
  VSURG_INT,
  VSAG_INT,
  STATUS,
  STATUS_SET,
  STATUS_RESET,
  DIO_STATE,
  CYCLE,
  FRAME_LO,
  FRAME_HI,
  DIVISOR,
  HARM,
  DEV_ADDR,
  CONTROL,
  CONFIG,
  VTARGET,
  VSURG_VAL,
  VSAG_VAL,
  VRMS_MIN,
  VRMS_MAX,
  VA_RMS,
  VB_RMS,
  VA_FUND,
  VB_FUND,
  VA_HARM,
  VB_HARM,
  VC_RMS,
  RESERVED_50,
  VA,
  VB,
  VQA,
  VQB,
  VC,
  SINE,
  COSINE,
  VA_PEAK,
  VB_PEAK,
  ITARGET,
  IRMS_MIN,
  IA_RMS,
  IB_RMS,
  IA_FUND,
  IB_FUND,
  IA_HARM,
  IB_HARM,
  IA,
  IB,
  IA_PEAK,
  IB_PEAK,
  IRMS_MAX,
  IARMS_MAX,
  IBRMS_OFFS,
  WATT_A,
  WATT_B,
  WATT_C,
  VA_A,
  VA_B,
  VA_C,
  VAR_A,
  VAR_B,
  VAR_C,
  PFUND_A,
  PFUND_B,
  PHARM_A,
  PHARM_B,
  QFUND_A,
  QFUND_B,
  QHARM_A,
  QHARM_B,
  PA,
  PB,
  PQA,
  PQB,
  WATT_MAX,
  PA_OFFS,
  QA_OFFS,
  PB_OFFS,
  QB_OFFS,
  PFA,
  PFB,
  PFC,
  RESERVED_104,
  TEMPC,
  T_TARGET,
  T_MIN,
  T_MAX,
  FREQ,
  F_MIN,
  F_MAX,
  RESERVED_112,
  MIN1,
  MIN2,
  MIN3,
  MIN4,
  MIN5,
  MIN6,
  MAX1,
  MAX2,
  MAX3,
  MAX4,
  MAX5,
  MAX6,
  MM_ADDR1,
  MM_ADDR2,
  MM_ADDR3,
  MM_ADDR4,
  MM_ADDR5,
  MM_ADDR6,
  VFSCALE,
  IFSCALE,
  SCRATCH1,
  SCRATCH2,
  SCRATCH3,
  SCRATCH4,
  BUCKET_LOW,
  BUCKET_HI,
  IA_CREST,
  IB_CREST,
  RESERVED_141,
  RESERVED_142,
  PA_POS_CNT,
  RESERVED_144,
  RESERVED_145,
  PA_NEG_CNT,
  RESERVED_147,
  RESERVED_148,
  PB_POS_CNT,
  RESERVED_150,
  RESERVED_151,
  PB_NEG_CNT,
  RESERVED_153,
  RESERVED_154,
  PQA_POS_CNT,
  RESERVED_156,
  RESERVED_157,
  PQA_NEG_CNT,
  RESERVED_159,
  RESERVED_160,
  PQB_POS_CNT,
  RESERVED_162,
  RESERVED_163,
  PQB_NEG_CNT,
  RESERVED_165,
  RESERVED_166,
  SA_CNT,
  RESERVED_168,
  RESERVED_169,
  SB_CNT,
  RYA_TON,
  RYB_TON,
  RYA_TOFF,
  RYB_TOFF,
  RYA_CNT,
  RYB_CNT,
  BAUD,
  DIO_POL,
  DIO_DIR
}
emd_register_t;


/**********************************************************************
 STATUS, STATUS_RESET, STATUS_SET, STICKY, MASK registers bit 
 descriptions
**********************************************************************/
#define DRDY     0x800000
#define MMUPD    0x400000
#define VA_SAG   0x200000
#define VB_SAG   0x100000
#define SIGN_VA  0x080000
#define SIGN_VB  0x040000
#define OV_TEMP  0x020000
#define UN_TEMP  0x010000
#define OV_FREQ  0x008000
#define UN_FREQ  0x004000
#define OV_VRMSA 0x002000
#define UN_VRMSA 0x001000
#define OV_VRMSB 0x000800
#define UN_VRMSB 0x000400
#define VA_SURGE 0x000200
#define VB_SURGE 0x000100
#define OV_WATT1 0x000080
#define OV_WATT2 0x000040
#define OV_AMP1  0x000020
#define OV_AMP2  0x000010
#define XSTATE   0x000008
#define RELAY1   0x000004
#define RELAY2   0x000002
#define RESET    0x000001


/**********************************************************************
 DIO_STATE and DIO_POL register bit descriptions
**********************************************************************/
//23:11 Reserved
#define MP10      0x000400 //SPI, UART, I2C
#define IFC1      0x000200 //SPI, UART, I2C
#define IFC0      0x000100 //SPI, UART, I2C
#define MP7       0x000080 //SPI, UART, I2C
#define MP6       0x000040 //SPI
#define ADDR1     0x000040 //UART, I2C
#define SSB       0x000020 //SPI
#define RS485_DIR 0x000020 //UART
#define SCL       0x000020 //I2C
#define MP4       0x000010 //SPI,UART,I2C
#define SDO       0x000008 //SPI
#define TXD       0x000008 //UART
#define SDAO      0x000008 //I2C
#define SDI       0x000004 //SPI
#define RXD       0x000004 //UART
#define SDAI      0x000004 //I2C
#define SPCK      0x000002 //SPI
#define ADDR0     0x000002 //UART, I2C
#define MP0       0x000001 //SPI, UART, I2C


/**********************************************************************
 COMMAND general setting bit descriptions, and commands
**********************************************************************/
//General setting bits
#define FREQ 0x40
#define LL   0x20
#define TC   0x10

//Master commands, written to command register after being bitwise ORed with 
//user defined gen_settings var

//No Action, allows the user to disable temperature updates
#define STOP_TEMP_UPDATE 0x000400
#define EN_TEMP_UPDATE   0x000000

//Save to Flash Command
#define SAVE_TO_FLASH    0xACC200

//Clear Flash Storage 0
#define CLR_FLASH_0      0xACC000

//Clear Flash Storage 1 
#define CLR_FLASH_1      0xACC100

//Calibration Command - bitwise OR 'CALIBRATE' with desired bits and
//user defined gen_settings var
#define CALIBRATE  0xCA0000 //23:16
//bit 15 always 0 for cal command, the following are bits 14:8
#define CAL_BIT_S2 0x004000 
#define CAL_BIT_S0 0x002000
#define CAL_BIT_S3 0x001000
#define CAL_BIT_S1 0x000800
#define CAL_BIT_T  0x000400
#define CAL_BIT_O  0x000200
#define CAL_BIT_XT 0x000100

//Soft reset, no general setting bits. 15:0 =0x0000.
#define SOFT_RESET 0xBD0000


/**********************************************************************
 CONTROL register bit descriptions
**********************************************************************/
//23:3 reserved for future use
#define CLR_ENERGY_ACC   0x000004
#define CLR_ENERGY_CNTRS 0x000002
#define RST_MIN_MAX_TRCK 0x000001


/**********************************************************************
 CONFIG register bit descriptions
**********************************************************************/
#define V_REF_S0          0
#define V_REF_S2          0x400000
#define V_REF_S0_MINUS_S2 0x800000
#define V_REF_S0_PLUS_S2  0xC00000

#define VC_M2_NEG  0
#define VC_M2_ZERO 0x040000
#define VC_M2_ONE  0x080000
#define VC_M2_TWO  0x0C0000
#define VC_M0_NEG  0
#define VC_M0_ZERO 0x010000
#define VC_M0_ONE  0x020000
#define VC_M0_TWO  0x030000

#define VB_M2_NEG  0
#define VB_M2_ZERO 0x004000
#define VB_M2_ONE  0x008000
#define VB_M2_TWO  0x00C000
#define VB_M0_NEG  0
#define VB_M0_ZERO 0x001000
#define VB_M0_ONE  0x002000
#define VB_M0_TWO  0x003000

#define VA_M2_NEG  0
#define VA_M2_ZERO 0x000400
#define VA_M2_ONE  0x000800
#define VA_M2_TWO  0x000C00
#define VA_M0_NEG  0
#define VA_M0_ZERO 0x000100
#define VA_M0_ONE  0x000200
#define VA_M0_TWO  0x000300

#define IB_M2_NEG  0
#define IB_M2_ZERO 0x000040
#define IB_M2_ONE  0x000080
#define IB_M2_TWO  0x0000C0
#define IB_M0_NEG  0
#define IB_M0_ZERO 0x000010
#define IB_M0_ONE  0x000020
#define IB_M0_TWO  0x000030

#define IA_M2_NEG  0
#define IA_M2_ZERO 0x000004
#define IA_M2_ONE  0x000008
#define IA_M2_TWO  0x00000C
#define IA_M0_NEG  0
#define IA_M0_ZERO 0x000001
#define IA_M0_ONE  0x000002
#define IA_M0_TWO  0x000003

#endif /*__78M6610_LMU_H*/


/**********************************************************************
* Copyright (C) 2013 Maxim Integrated Products, Inc., All Rights Reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
* IN NO EVENT SHALL MAXIM INTEGRATED BE LIABLE FOR ANY CLAIM, DAMAGES
* OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*
* Except as contained in this notice, the name of Maxim Integrated
* Products, Inc. shall not be used except as stated in the Maxim Integrated
* Products, Inc. Branding Policy.
*
* The mere transfer of this software does not imply any licenses
* of trade secrets, proprietary technology, copyrights, patents,
* trademarks, maskwork rights, or any other form of intellectual
* property whatsoever. Maxim Integrated Products, Inc. retains all
* ownership rights.
**********************************************************************/
