/**********************************************************************
* File: 78M6610_PSU.h
* Programmer: Justin Jordan
* Started: 26JUN14
* Updated: 14AUG14
*
* Description: 78M6610+LMU addresses and specific commands.
*
**********************************************************************/


#ifndef __78M6610_PSU_H
#define __78M6610_PSU_H

#define MAX_PACKET_LEN 255 

#define MAX_REG_ADRS 0x7F  //max word address

/******************** 78M6610+LMU register defenitions ****************
  Names follow word addresses; 0, 1, 2, etc.  maxim_ssi.c functions 
  that use these addresses will multiply by 3 to get byte addresses, 
  just use the name of the address in the argument of the functions.
**********************************************************************/
typedef enum 
{
  COMMAND,
  FW_VERSION,
  PHASE_COMP,
  ALARM_MASK1,
  ALARM_SET,
  ALARM_RESET,
  TEMPERATURE,
  VA,
  VAR,
  V_RMS,
  I_RMS,
  WATT,
  P_AVERAGE,
  PF,
  FREQUENCY,
  DEVADDR,
  ALARMS,
  V_FUND,
  I_FUND,
  P_FUND,
  Q_FUND,
  VA_FUND,
  V_HARM,
  I_HARM,
  P_HARM,
  Q_HARM,
  VA_HARM,
  ALARM_MASK2,
  STICKY,
  I_LOW,
  I_HIGH,
  I_PEAK,
  V_LOW,
  V_HIGH,
  V_PEAK,
  V_SURGE_TH,
  V_SAG_TH,
  V_MIN_TH,
  V_MAX_TH,
  V_DROP_TH,
  I_MAX_TH,
  P_MAX_TH,
  T_MIN_TH,
  T_MAX_TH,
  TEMP1_THRES,
  TEMP2_THRES,
  F_MIN_TH,
  F_MAX_TH,
  VSAG_VSURGE_HO,
  RESERVED_50,
  VMIN_VMAX_HO,
  I_MAX_HO,
  P_MAX_HO,
  TMIN_TMAX_HO,
  FMIN_FMAX_HO,
  I_RMS_OFFSET,
  V_RMS_OFFSET,
  P_OFFSET,
  T_MIN_CNT,
  T_MAX_CNT,
  V_MIN_CNT,
  V_MAX_CNT,
  I_MAX_CNT,
  P_MAX_CNT,
  F_MIN_CNT,
  F_MAX_CNT,
  V_SAG_CNT,
  V_SURGE_CNT,
  ACCUM_CYC,
  P_TARGET,
  BAUD,
  EXT_TEMP1,
  EXT_TEMP2,
  TEMP1_GAIN,
  TEMP2_GAIN,
  HPF_COEFF_I,
  HPF_COEFF_V,
  I_TARGET,
  V_TARGET,
  CAL_CYC,
  I_GAIN,
  V_GAIN,
  I_OFFSET,
  V_OFFSET,
  T_GAIN,
  T_OFFSET,
  SYS_GAIN,
  HARM,
  S_ACCUM,
  ACCUM,
  DIVISOR,
  FRAME_LO,
  FRAME_HI,
  XY_COMP,
  R_COMP,
  I_SCALE,
  V_SCALE,
  P_SCALE,
  PF_SCALE,
  F_SCALE,
  T_SCALE,
  RLY_ON_MIN,
  RLY_ON_MAX,
  RLY_ON_TIME,
  RLY_OFF_MIN,
  RLY_OFF_MAX,
  RLY_OFF_TIME,
  RLY_ON_DLY,
  RLY_OFF_DLY,
  DIO_STATE,
  TEMP_COMP1,
  TEMP_COMP2,
  RESERVED_112,
  RESERVED_113,
  I_RMS_1,
  V_RMS_1,
  POWER_1,
  VAR_1,
  VA_1,
  PF_1,
  FREQ_1,
  HI_RATE_V,
  HI_RATE_I,
  HI_RATE_VQ,
  HI_RATE_P,
  HI_RATE_PQ,
  HI_RATE_CYC,
  HI_RATE_SCYC 
}
emd_register_t;


/**********************************************************************
DIO_STATE register bit descriptions
**********************************************************************/

#define MP1      0x000400
#define MP0      0x000200
#define IFCONFIG 0x000100
#define ACFAULT  0x000080
#define ADDR1    0x000040
#define SSB      0x000020
#define DIR      0x000020
#define SCL      0x000020
#define ACCRIT   0x000010
#define SDO      0x000008
#define TX       0x000008
#define SDAO     0x000008
#define SDI      0x000004
#define RX       0x000004
#define SDAI     0x000004
#define SPCK     0x000002
#define ADDR0    0x000002
#define RLYCTL   0x000001


/**********************************************************************
Alarm Status/Sticky/Mask1/Mask2/Set/Reset register bit descriptions
**********************************************************************/

#define DATA_RDY     0x800000
#define OVR_TMP      0x400000
#define UNDR_TMP     0x200000
#define EXT_OVR_TMP1 0x080000
#define EXT_OVR_TMP2 0x040000
#define VSAG         0x000800
#define VSURGE       0x000400
#define VDROP_OUT    0x000200
#define OVR_VOLT     0x000100
#define UNDR_VOLT    0x000080
#define OVR_CURNT    0x000040
#define OVR_PWR      0x000020
#define OVR_FRQ      0x000010
#define UNDR_FRQ     0x000008
#define RLY_ON       0x000004 //does not apply to sticky
#define ZERO_CRSS    0x000002 //does not apply to sticky


/**********************************************************************
 COMMAND general setting bit descriptions, and commands
**********************************************************************/
//General setting bits
#define FREQ 0x40
#define LL   0x20
#define TC   0x10
#define AR   0x08
#define AY   0x04

//Master commands, written to command register after being bitwise ORed with 
//user defined gen_settings var

//No Action, allows the user to disable temperature updates
#define STOP_TEMP_UPDATE 0x000400
#define EN_TEMP_UPDATE   0x000000

//Save to Flash Command
#define SAVE_TO_FLASH    0xACC200

//Clear Flash Storage 0
#define CLR_FLASH_0      0xACC000

//Clear Flash Storage 1 
#define CLR_FLASH_1      0xACC100

//Calibration Command - bitwise OR 'CALIBRATE' with desired bits and
//user defined gen_settings var
#define CALIBRATE  0xCA0000 //23:16
//bit 15 and 14 always 0 for cal command, the following are bits 13:8

#define CAL_BIT_XYR 0x002000
#define CAL_BIT_V   0x001000
#define CAL_BIT_I   0x000800
#define CAL_BIT_T   0x000400
#define CAL_BIT_O   0x000200
#define CAL_BIT_XT  0x000100

#endif /*__78M6610_PSU_H*/


/**********************************************************************
* Copyright (C) 2013 Maxim Integrated Products, Inc., All Rights Reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
* IN NO EVENT SHALL MAXIM INTEGRATED BE LIABLE FOR ANY CLAIM, DAMAGES
* OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*
* Except as contained in this notice, the name of Maxim Integrated
* Products, Inc. shall not be used except as stated in the Maxim Integrated
* Products, Inc. Branding Policy.
*
* The mere transfer of this software does not imply any licenses
* of trade secrets, proprietary technology, copyrights, patents,
* trademarks, maskwork rights, or any other form of intellectual
* property whatsoever. Maxim Integrated Products, Inc. retains all
* ownership rights.
**********************************************************************/
