/**********************************************************************
* File: MAX78630_.h
* Programmer: Justin Jordan
* Started: 26JUN14
* Updated: 14AUG14
*
* Description: MAX78630+PPM addresses and specific commands.
*
**********************************************************************/


#ifndef __MAX78630_PPM_H
#define __MAX78630_PPM_H

#define MAX_PACKET_LEN 255 

#define MAX_REG_ADRS 0xC1  //max word address

/******************** MAX78630+PPM register defenitions ***************
  Names follow word addresses; 0, 1, 2, etc.  maxim_ssi.c functions 
  that use these addresses will multiply by 3 to get byte addresses, 
  just use the name of the address in the argument of the functions.
**********************************************************************/
typedef enum
{
  COMMAND,
  FW_VERSION,
  CONFIG,
  SAMPLES,
  DIVISOR,
  CYCLE,
  FRAME,
  STATUS,
  STATUS_CLEAR,
  STATUS_SET,
  MASK1,
  MASK2,
  MASK3,
  MASK4,
  MASK5,
  STICKY,
  DIO_STATE,
  DIO_DIR,
  DIO_POL,
  CALCYCS,
  HPF_COEF_I,
  HPF_COEF_V,
  PHASECOMP1,
  PHASECOMP2,
  PHASECOMP3,
  HARM,
  DEVADDR,
  BAUD,
  I1_GAIN,
  I2_GAIN,
  I3_GAIN,
  V1_GAIN,
  V2_GAIN,
  V3_GAIN,
  I1_OFFS,
  I2_OFFS,
  I3_OFFS,
  V1_OFFS,
  V2_OFFS,
  V3_OFFS,
  T_GAIN,
  T_OFFS,
  VSAG_INT,
  V_IMB_MAX,
  I_IMB_MAX,
  VA,
  VB,
  VC,
  VA_RMS,
  VB_RMS,
  VC_RMS,
  VT_RMS,
  VFUND_A,
  VFUND_B,
  VFUND_C,
  VHARM_A,
  VHARM_B,
  VHARM_C,
  V_TARGET,
  VRMS_MIN,
  VRMS_MAX,
  VSAG_LIM,
  INST_A,
  INST_B,
  INST_C,
  IARMS_OFF,
  IBRMS_OFF,
  ICRMS_OFF,
  IA_PEAK,
  IB_PEAK,
  IC_PEAK,
  IA_RMS,
  IB_RMS,
  IC_RMS,
  IT_RMS,
  IFUND_A,
  IFUND_B,
  IFUND_C,
  IHARM_A,
  IHARM_B,
  IHARM_C,
  IRMS_MAX,
  I_TARGET,
  QFUND_A,
  QFUND_B,
  QFUND_C,
  QHARM_A,
  QHARM_B,
  QHARM_C,
  QA_OFFS,
  QB_OFFS,
  QC_OFFS,
  PA_OFFS,
  PB_OFFS,
  PC_OFFS,
  WATT_A,
  WATT_B,
  WATT_C,
  VAR_A,
  VAR_B,
  VAR_C,
  VA_A,
  VA_B,
  VA_C,
  WATT_T,
  VAR_T,
  VA_T,
  IFSCALE,
  VSCALE,
  RESERVED_6D,
  PFUND_A,
  PFUND_B,
  PFUND_C,
  PHARM_A,
  PHARM_B,
  PHARM_C,
  VAFUNDA,
  VAFUNDB,
  VAFUNDC,
  PFA,
  PFB,
  PFC,
  PF_T,
  PF_MIN,
  TEMPC,
  T_TARGET,
  T_MIN,
  T_MAX,
  FREQ,
  F_MIN,
  F_MAX,
  MIN0,
  MIN1,
  MIN2,
  MIN3,
  MIN4,
  MIN5,
  MIN6,
  MIN7,
  MAX0,
  MAX1,
  MAX2,
  MAX3,
  MAX4,
  MAX5,
  MAX6,
  MAX7,
  MMADDR0,
  MMADDR1,
  MMADDR2,
  MMADDR3,
  MMADDR4,
  MMADDR5,
  MMADDR6,
  MMADDR7,
  BUCKET_LOW,
  BUCKET_HI,
  RESERVED_9D,
  RESERVED_9E,
  WHA_POS,
  RESERVED_A0,
  RESERVED_A1,
  WHA_NEG,
  RESERVED_A3,
  RESERVED_A4,
  WHB_POS,
  RESERVED_A6,
  RESERVED_A7,
  WHB_NEG,
  RESERVED_A9,
  RESERVED_AA,
  WHC_POS,
  RESERVED_AC,
  RESERVED_AD,
  WHC_NEG,
  RESERVED_AF,
  RESERVED_B0,
  VARHA_POS,
  RESERVED_B2,
  RESERVED_B3,
  VARHA_NEG,
  RESERVED_B5,
  RESERVED_B6,
  VARHB_POS,
  RESERVED_B8,
  RESERVED_B9,
  VARHB_NEG,
  RESERVED_BB,
  RESERVED_BC,
  VARHC_POS,
  RESERVED_BE,
  RESERVED_BF,
  VARHC_NEG,
  SYSSTAT
}emd_register_t;


/**********************************************************************
 STATUS, STATUS_RESET, STATUS_SET, STICKY, MASK registers bit 
 descriptions
**********************************************************************/
#define DRDY     0x800000
#define OV_FREQ  0x400000
#define UN_FREQ  0x200000
#define OV_TEMP  0x100000
#define UN_TEMP  0x080000
#define OV_VRMSC 0x040000
#define UN_VRMSC 0x020000
#define OV_VRMSB 0x010000
#define UN_VRMSB 0x008000
#define OV_VRMSA 0x004000
#define UN_VRMSA 0x002000
#define UN_PFC   0x001000
#define UN_PFB   0x000800
#define UN_PFA   0x000400
#define OV_IRMSC 0x000200
#define OV_IRMSB 0x000100
#define OV_IRMSA 0x000080
#define VC_SAG   0x000040
#define VB_SAG   0x000020
#define VA_SAG   0x000010
#define V_IMBAL  0x000008
#define I_IMBAL  0x000004
#define XSTATE   0x000002
#define RESET    0x000001


/**********************************************************************
 DIO_STATE, DIO_DIR and DIO_POL register bit descriptions
**********************************************************************/
//23:16 reserved
#define DIO15 0x008000
#define DIO14 0x004000
#define DIO13 0x002000
#define DIO12 0x001000
#define DIO11 0x000800
#define DIO10 0x000400
#define DIO9  0x000200
#define DIO8  0x000100
#define DIO7  0x000080
#define DIO6  0x000040
#define DIO5  0x000020
#define DIO4  0x000010
#define DIO3  0x000008
#define DIO2  0x000004
#define DIO1  0x000002
#define DIO0  0x000001
//other names
#define SPCK      0x000002
#define ADDR0     0x000002
#define SDI       0x000004
#define RXD       0x000004
#define SDAI      0x000004
#define SDO       0x000008
#define TXD       0x000008
#define SDAO      0x000008
#define SSB       0x000020
#define RS485_DIR 0x000020
#define SCL       0x000020
#define ADDR1     0x000040
#define IFC0      0x000100
#define IFC1      0x000200


/**********************************************************************
 COMMAND general setting bit descriptions, and commands
**********************************************************************/
//General setting bits
//3:0 reserved
#define GENERAL_REN  0x80
#define GENERAL_RTRK 0x40
#define GENERAL_LL   0x20
#define GENERAL_TC   0x10

//Master commands, written to command register after being bitwise ORed 
//with user defined gen_settings var

//No Action, allows the user to disable temperature updates
#define STOP_TEMP_UPDATE 0x000400
#define EN_TEMP_UPDATE   0x000000

//Save to Flash Command
#define SAVE_TO_FLASH    0xACC200

//Clear Flash Storage 0
#define CLR_FLASH_0      0xACC000

//Clear Flash Storage 1 
#define CLR_FLASH_1      0xACC100

//Calibration Command - bitwise OR 'CALIBRATE' with desired bits and
//user defined gen_settings var
#define CALIBRATE          0xD40000 //(0x65 << 1) = bits 23:17 per datasheet
#define CAL_VC             0x010000
#define CAL_VB             0x008000
#define CAL_VA             0x004000
#define CAL_IC             0x002000
#define CAL_IB             0x001000
#define CAL_IA             0x000800
#define CAL_TEMP           0x000400
#define CAL_OFFSET_VS_GAIN 0x000200
#define CAL_EXT_TEMP_GAIN  0x000100


/**********************************************************************
 CONFIG register bit descriptions
**********************************************************************/
//bit 23 reserved, write as zero
#define INV_AV3     0x400000
#define INV_AV2     0x200000
#define INV_AV1     0x100000
#define VSGNC       0x080000
#define VSGNB       0x040000
#define VSGNA       0x020000
#define EN_ROGC     0x010000
#define EN_ROGB     0x008000
#define EN_ROGA     0x004000
#define EN_PREAMPA  0x002000
//bit 12 reserved, write as zero
#define EN_PREAMPB  0x000800
//bit 10 reserved, write as zero
#define EN_PREAMPC  0x000200
//bit 8 reserved, write as zero
//Following are for bit 7:6
#define PPHASE_NONE 0x000000
#define PPHASE_A    0x000040
#define PPHASE_B    0x000080
#define PPHASE_C    0x0000C0
//bit 5
#define VDELTA      0x000020
//Following are for bit 4:3
#define VPHASE_NONE 0x000000
#define VPHASE_AV1  0x000008
#define VPHASE_AV2  0x000010
#define VPHASE_AV3  0x000018
//bit 2
#define INEUTRAL    0x000004
//Following are for bit 1:0
#define IPHASE_NONE 0x000000
#define IPHASE_AI1  0x000001
#define IPHASE_AI2  0x000002
#define IPHASE_AI3  0x000003

#endif /*__MAX78630_PPM_H*/


/**********************************************************************
* Copyright (C) 2013 Maxim Integrated Products, Inc., All Rights Reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
* IN NO EVENT SHALL MAXIM INTEGRATED BE LIABLE FOR ANY CLAIM, DAMAGES
* OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*
* Except as contained in this notice, the name of Maxim Integrated
* Products, Inc. shall not be used except as stated in the Maxim Integrated
* Products, Inc. Branding Policy.
*
* The mere transfer of this software does not imply any licenses
* of trade secrets, proprietary technology, copyrights, patents,
* trademarks, maskwork rights, or any other form of intellectual
* property whatsoever. Maxim Integrated Products, Inc. retains all
* ownership rights.
**********************************************************************/
